@@ -1,31 +1,18 @@
 /*
- *   Copyright 2017 by Ivan Cukic <ivan.cukic (at) kde.org>
+ *   SPDX-FileCopyrightText: 2017 Ivan Cukic <ivan.cukic (at) kde.org>
  *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License or (at your option) version 3 or any later version
- *   accepted by the membership of KDE e.V. (or its successor approved
- *   by the membership of KDE e.V.), which shall act as a proxy
- *   defined in Section 14 of version 3 of the license.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "backendchooserwidget.h"
 
 #include "ui_backendchooserwidget.h"
 
-#include "vault.h"
 #include "engine/backend_p.h"
+#include "vault.h"
 
-class BackendChooserWidget::Private {
+class BackendChooserWidget::Private
+{
 public:
     Private(BackendChooserWidget *parent)
         : q(parent)
@@ -51,11 +38,9 @@ public:
         q->setIsValid(vaultNameValid && backendValid);
     }
 
-    BackendChooserWidget * const q;
+    BackendChooserWidget *const q;
 };
 
-
-
 BackendChooserWidget::BackendChooserWidget()
     : DialogDsl::DialogModule(false)
     , d(new Private(this))
@@ -64,23 +49,19 @@ BackendChooserWidget::BackendChooserWidget()
     d->ui.textStatus->hide();
     d->ui.page2Layout->setRowStretch(1, 10);
 
-    connect(d->ui.editVaultName, &QLineEdit::textChanged,
-            this, [&] (const QString &vaultName) {
-                d->setVaultNameValid(!vaultName.isEmpty());
-            });
+    connect(d->ui.editVaultName, &QLineEdit::textChanged, this, [&](const QString &vaultName) {
+        d->setVaultNameValid(!vaultName.isEmpty());
+    });
 
-    connect(d->ui.comboBackend, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
-            this, &BackendChooserWidget::checkCurrentBackend);
+    connect(d->ui.comboBackend, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &BackendChooserWidget::checkCurrentBackend);
 
-    connect(d->ui.pickBackendButton, SIGNAL(clicked()), this, SLOT(showBackendSelector()));
+    connect(d->ui.pickBackendButton, &QPushButton::clicked, this, &BackendChooserWidget::showBackendSelector);
 }
 
-
 BackendChooserWidget::~BackendChooserWidget()
 {
 }
 
-
 void BackendChooserWidget::checkCurrentBackend()
 {
     const auto backendId = d->ui.comboBackend->currentData().toString();
@@ -110,7 +91,6 @@ void BackendChooserWidget::checkCurrentBackend()
     d->setBackendValid(backendValid);
 }
 
-
 void BackendChooserWidget::showBackendSelector()
 {
     d->ui.vaultEncryptionConfig->setCurrentWidget(d->ui.page2);
@@ -134,17 +114,13 @@ void BackendChooserWidget::addItem(const QByteArray &id, const QString &title, i
     }
 }
 
-
 PlasmaVault::Vault::Payload BackendChooserWidget::fields() const
 {
     QByteArray backend = d->bestsBackend;
     if (d->ui.vaultEncryptionConfig->currentWidget() == d->ui.page2)
         backend = d->ui.comboBackend->currentData().toByteArray();
     Q_ASSERT(!backend.isEmpty());
-    return {
-        { KEY_BACKEND, backend},
-        { KEY_NAME,    d->ui.editVaultName->text() }
-    };
+    return {{KEY_BACKEND, backend}, {KEY_NAME, d->ui.editVaultName->text()}};
 }
 
 void BackendChooserWidget::checkBackendAvailable()
@@ -153,3 +129,5 @@ void BackendChooserWidget::checkBackendAvailable()
         showBackendSelector(); // show the more helpful selector
     }
 }
+
+#include "moc_backendchooserwidget.cpp"
